@@ -2,7 +2,8 @@
 
 import sys
 
-class Digraph():
+
+class Digraph:
     def __init__(self, arg):
         self.E = 0
         if type(arg) is int:
@@ -10,7 +11,7 @@ class Digraph():
             self.G = [[] for i in range(self.V)]
             return
 
-        infile = arg # assume string
+        infile = arg  # assume string
         with open(infile) as f:
             self.V = int(f.readline())
             E = int(f.readline())
@@ -21,7 +22,6 @@ class Digraph():
         assert self.E == E
         f.close()
 
-
     def add_edge(self, v, w):
         assert v < self.V
         assert w < self.V
@@ -29,19 +29,16 @@ class Digraph():
         self.E += 1
         return
 
-
     def adj(self, v):
         assert v < self.V
         return self.G[v]
 
-
     def reverse(self):
         DG = Digraph(self.V)
         for v in range(self.V):
             for w in self.adj(v):
                 DG.add_edge(w, v)
-        return  DG
-
+        return DG
 
     def to_string(self):
         s = f'G: {self.V} vertices, {self.E} edges'
