@@ -6,7 +6,7 @@ from graphe.digraph import ddfo
 from collections import deque
 
 
-class KnSSCC():
+class KnSSCC:
     def __init__(self, Digraph):
         self.count = 0
         self.marked = [False for i in range(Digraph.V)]
@@ -20,6 +20,7 @@ class KnSSCC():
                 self.dfs(Digraph, v)
                 self.count += 1
 
+        assert check(G)
 
     def dfs(self, Digraph, v):
         self.marked[v] = True
@@ -28,23 +29,19 @@ class KnSSCC():
             if not self.marked[w]:
                 self.dfs(Digraph, w)
 
-
     def strongly_connected(self, v, w):
         return self.id[v] == self.id[w]
 
-
     def get_id(self, v):
         return self.id[v]
 
-
     def get_count(self):
         return self.count
 
 
-
 if __name__ == '__main__':
 
-    DG = digraph.Digraph('../../data/tinyDG.txt')
+    DG = digraph.Digraph('../../../data/tinySCDG.txt')
 
     SCC = KnSSCC(DG)
 
