@@ -4,10 +4,11 @@ import sys
 
 from graphe.digraph import digraph
 
-class SymbolDigraph():
+
+class SymbolDigraph:
     def __init__(self, infile, sc=' '):
-        self.keys = [] # vertice index to name
-        self.ST = {} # vertice name to index
+        self.keys = []  # vertice index to name
+        self.ST = {}  # vertice name to index
 
         lines = open(infile).read().splitlines()
         for line in lines:
@@ -32,17 +33,15 @@ class SymbolDigraph():
                 w = self.ST[i]
                 self.DG.add_edge(v, w)
 
-
     def graph(self):
         return self.DG
 
-
     def node_names(self):
         return self.keys
 
 
 if __name__ == '__main__':
     sg = SymbolDigraph('../../../data/routes.txt')
-    assert sg.G.V == 10
-    assert sg.G.E == 18
+    assert sg.DG.V == 10
+    assert sg.DG.E == 18
     assert sg.keys[0] == 'JFK'
