@@ -2,19 +2,20 @@
 
 
 from graphe.digraph import symboldigraph
+from graphe.digraph import digraph
 from graphe.digraph import cycle
 from graphe.digraph import ddfo
 
 
-class Topological():
+class Topological:
     def __init__(self, G):
         assert isinstance(G, digraph.Digraph)
         self.G = G
         self.rank = [-1 for i in range(self.G.V)]
 
-        cycle = cycle.DirectedCycle(G)
-        if cycle.has_cycle():
-            print('Topological sort not - graph has cycle')
+        cyc = cycle.DirectedCycle(self.G)
+        if cyc.has_cycle():
+            print('Topological sort not possible - graph has cycle')
             raise Exception('G has cycle')
 
         dfo = ddfo.DepthFirstOrder(self.G)
@@ -23,7 +24,6 @@ class Topological():
         for i, v in enumerate(self.order):
             self.rank[v] = i
 
-
     def get_order(self):
         return self.order
 
@@ -32,7 +32,7 @@ if __name__ == '__main__':
 
     SG = symboldigraph.SymbolDigraph('../../../data/jobs.txt', '/')
 
-    TS = Topological(SG.G)
+    TS = Topological(SG.DG)
     names = SG.node_names()
     for v in TS.get_order():
         print(f'{v} {names[v]}')
