@@ -3,14 +3,14 @@
 import sys
 from collections import deque
 
-class BFSearch():
+
+class BFSearch:
     def __init__(self, G, s):
         self.marked = [False for i in range(G.V)]
         self.edgeTo = [-1 for i in range(G.V)]
         self.s = s
         self.bfs(G, s)
 
-
     def bfs(self, Graph, s):
         Q = deque()
         self.marked[s] = True
@@ -23,11 +23,9 @@ class BFSearch():
                     self.marked[w] = True
                     Q.append(w)
 
-
     def has_path_to(self, v):
         return self.marked[v]
 
-
     def path_to(self, v):
         path = []
         if not self.has_path_to(v):
@@ -39,6 +37,5 @@ class BFSearch():
         path.append(self.s)
         return path
 
-
     def count(self):
         return sum([1 for x in self.marked if x == True]) - 1
